/*
 *   Copyright (C) 2019 CERN.
 *   Copyright (C) 2019 Northwestern University.
 *
 * Invenio App RDM is free software; you can redistribute it and/or modify it
 * under the terms of the MIT License; see LICENSE file for more details.
 */

@navbar_background_image: linear-gradient(20deg, rgba(3, 119, 205, 1), rgba(3, 119, 205, 1) 52.52%, rgba(251, 130, 115, 1));
@navbar_background_color: unset;

@signupColor: @green;
@searchButtonColor: #fb8273;

@coverPageDefaultMargin: 0;
