/*
 *   Copyright (C) 2019 CERN.
 *   Copyright (C) 2019 Northwestern University.
 *
 * Invenio App RDM is free software; you can redistribute it and/or modify it
 * under the terms of the MIT License; see LICENSE file for more details.
 */

 #footer {
   color: #fff;
   margin-top: auto;

  &.footer-bottom {
    background-color: #0377cd;
    padding-top: 15px;
    padding-bottom: 15px;
    font-weight: 300;
    font-size: 14px;

    a {
      text-decoration: none;
      color: #ffffffd6;
      font-weight: 600;

      &:hover, &:focus {
        color: #ffffff;
      }
    }
  }

}
