/*
 *   Copyright (C) 2019-2020 CERN.
 *   Copyright (C) 2019-2020 Northwestern University.
 *
 * Invenio App RDM is free software; you can redistribute it and/or modify it
 * under the terms of the MIT License; see LICENSE file for more details.
 */

@import "variables.less";
@import "footer.less";
@import "frontpage.less";
@import "deposit.less";

html,
body {
  color: #000;
  width: 100%;
  height: 100vh;
  display: flex;
  flex-direction: column;
}

.outer-navbar {
  background-image: @navbar_background_image;
  background-color: @navbar_background_color;
  border-color: transparent;
  padding: 8px;

  #invenio-nav {
    background: transparent;
  }

  #frontpage-search-bar{
    background: transparent;
  }

  a{
    color: #dbeaff;
  }
}

.item.right-menu {
  line-height: 44px !important;
}

#invenio-nav .item.navbar-options {
  display: inline-block;
  vertical-align: middle;
  line-height: 44px;
}

.item.navbar-options {
  padding: 0 !important;

  li a {
    display: block;
    padding: .8em 1em;
  }

  :hover {
    color: white;
    background-color: rgba(255,255,255,.2);
  }
}


.no-dots-list {
  list-style-type:none;
  margin-block-start: unset;
  margin-block-end: unset;
}

.item.navbar-options:first-of-type {
  margin-left: 2em;
}

.centered {
  text-align: center;
}

.titlecase {
  text-transform: capitalize;
}

.rdm-logo {
  margin-right: -40px;
}

// Frontpage
.section-content-dark-bg,
.section-content-white-bg,
.section-content-light-bg {
  padding-top: calc(30px);
  padding-bottom: calc(2 * 30px);

  &:first-of-type {
    padding-top: 10px;
  }
}

.section-content-dark-bg {
  padding-top: calc(30px) !important;
  padding-bottom: calc(2 * 30px);
}

.section-content-white-bg {
  padding-top: calc(40px) !important;
  padding-bottom: calc(2 * 30px);
}

.section-content-light-bg {
  padding-top: calc(60px) !important;
  padding-bottom: calc(2 * 30px);
}

.section-content-white-bg a,
.section-content-light-bg a,
.hp-blog-section a {
  text-decoration: none;
  color: #0377cdb5;
  font-weight: 600;
}

.section-content-white-bg a:hover,
.section-content-white-bg a:focus,
.section-content-light-bg a:hover,
.section-content-light-bg a:focus,
.hp-blog-section a:hover,
.hp-blog-section a:focus {
  color: #0377cd;
}

.section-content-white-bg,
.section-content-light-bg {
  color: #333;
  width: 100%;
  text-align: justify;
  font-size: 1.2em;
  font-weight: 300;
}

.section-content-light-bg {
  background-color: rgba(173, 206, 224, 0.52);
}

.section-content-white-bg {
  background-color: #fff;
}

.section-content-white-bg h6,
.section-content-light-bg h6 {
  font-weight: 300;
  font-size: 1.4em;
  padding-bottom: 10px;
  color: #0377cd;
}

.section-title {
  -webkit-font-smoothing: antialiased;
  font-size: 2.5em;
  width: 100%;
  text-align: center;
  display: block;
  color: #0377cd;
  margin-bottom: 45px;
  font-weight: 500;
}

.section-subtitle {
  color: #0377cd !important;
  text-align: center;
  margin-bottom: 40px;
}

.invenio-rdm-project-goals {
  display: flex;
  flex-direction: row;
  margin: 60px 80px;

  i {
    font-size: 5em;
    color: #0377cd;
  }

  h3 {
    color: #0377cd;
  }

  .rdm-goal {
    margin-bottom: 20px;
  }
}

.get-started-section > .section-title {
  font-size: 2.65em;
}

@media only screen and (max-device-width: 768px) {
  .invenio-rdm-project-goals {
    flex-direction: column;
  }
}

.features-section img {
  max-height: 60px;
  max-width: 100%;
}
.features-section-row {
  padding-bottom: 30px;
}

.brought-to-you-section img,
.trusted-by-section img {
  max-height: 150px;
  max-width: 250px;
  margin: 20px;
  padding: 20px;
}

// Search page
.record-elem .record-title {
    color: #0377cd;
}

.record-elem .record-description {
    color: #000000;
}

.btn-primary  {
  background-color: #0377cd;
  border-color: #0377cd;
}

.panel-free-title {
  color: #0377cd;
}

// Log-in and sign-up
.cover-page {
  background-image: @navbar_background_image;
  background-color: @navbar_background_color;
  border-color: transparent;
}


// Deposits page
.header-row {
  background-color: #d7d7d7;
}

.item.deposits-list-item {
  .ui.grid .checkbox-column {
    display: flex;
    align-items: center;

    .icon {
      padding-left: 0.5em;
      padding-bottom: 20px;
    }
  }

  .actions > a,
  .stats > span {
    padding-right: 0.5em;
  }
}
