/*
 *   Copyright (C) 2020 CERN.
 *   Copyright (C) 2020 Northwestern University.
 *
 * Invenio App RDM is free software; you can redistribute it and/or modify it
 * under the terms of the MIT License; see LICENSE file for more details.
 */

/** Deposit page styles */

#deposit-form {

  .field label.title {
    background-color: #5aaad9;
    color: white;
    font-size: 1.05em;

    label {
      margin-left: 0.5rem;
    }
  }

  .save-button {
    margin-bottom: 0.5em;
  }

  .access-right {
    .inline.fields {
      margin-bottom: .75em;

      &:first-of-type {
        margin-top: 1em;
      }
    }
  }

}
